{{if $.Permission.CanRead $.UnitTypeIssues}}
{{.locale.Tr "repo.issues.context.reference_issue"}}
{{end}}
diff --git a/web_src/less/_base.less b/web_src/less/_base.less
index f2711c448..17e9ccfd3 100644
--- a/web_src/less/_base.less
+++ b/web_src/less/_base.less
@@ -1315,7 +1315,7 @@ footer {
}
.hide {
- display: none !important;
+ display: none;
&.show-outdated {
display: none !important;
diff --git a/web_src/less/modules/tippy.less b/web_src/less/modules/tippy.less
index 1fcd0372c..25dd7fc98 100644
--- a/web_src/less/modules/tippy.less
+++ b/web_src/less/modules/tippy.less
@@ -1,5 +1,10 @@
/* styles are based on node_modules/tippy.js/dist/tippy.css */
+// class to hide tippy target elements on page load
+.tippy-target {
+ display: none !important;
+}
+
[data-tippy-root] {
max-width: calc(100vw - 10px);
}
diff --git a/web_src/js/modules/tippy.js b/web_src/js/modules/tippy.js
index 87f9e8a4b..6f3adaddd 100644
--- a/web_src/js/modules/tippy.js
+++ b/web_src/js/modules/tippy.js
@@ -12,10 +12,11 @@ export function createTippy(target, opts = {}) {
...opts,
});
// for popups where content refers to a DOM element, we use the 'hide' class to initially hide
// the content, now we can remove it as the content has been removed from the DOM by tippy
if (opts.content instanceof Element) {
- opts.content.classList.remove('hide');
+ opts.content.classList.remove('tippy-target');
}
return instance;
@@ -12,10 +12,11 @@ export function createTippy(target, opts = {}) {
...opts,
});
- // for popups where content refers to a DOM element, we use the 'hide' class to initially hide
- // the content, now we can remove it as the content has been removed from the DOM by tippy
+ // for popups where content refers to a DOM element, we use the 'tippy-target' class
+ // to initially hide the content, now we can remove it as the content has been removed
+ // from the DOM by tippy
if (opts.content instanceof Element) {